==> abc-cli-0.2.37.tgz: package/webpack/webpack.daily.config.js <==
/**
 * @fileOverview webpack生产环境配置
 * @author langford@126.com
 */

'use strict'

const path = require('path')
const webpack = require('webpack')
const UglifyJsPlugin = require('uglifyjs-webpack-plugin')
const md5File = require('md5-file')
const HtmlWebpackPlugin = require('html-webpack-plugin')
const HtmlIncludeAssetsPlugin = require('html-webpack-include-assets-plugin')
const CleanWebpackPlugin = require('clean-webpack-plugin')
const MiniCssExtractPlugin = require('mini-css-extract-plugin')
const BundleAnalyzerPlugin = require('webpack-bundle-analyzer')
  .BundleAnalyzerPlugin
const _ = require('lodash')
const config = require('./webpack.base.config')({
  dev: false,
  env: 'production'
})
const utils = require('../utils')

const abcConfig = utils.abcConfig
const {
  dll,
  output,
  cleanBuild,
  analyzerReport,
  isExtractCss,
  outputDir,
  cssModule,
  staticPath
} = abcConfig
const prodConfig = abcConfig.env.daily || {}

config.entry =
  JSON.stringify(abcConfig.entry) === '{}'
    ? { index: './src/index.js' }
    : abcConfig.entry

let rules = []

// 未启用 cssModule 并且 isExtractCss 设置为 true，生成独立的 css 文件
if (isExtractCss && !cssModule.enable) {
  rules = [
    {
      test: /\.css$/,
      use: [
        MiniCssExtractPlugin.loader,
        {
          loader: 'css',
          options: {
            modules: false,
            minimize: true
          }
        },
        {
          loader: 'postcss',
          options: utils.getPostCssOptions()
        }
      ]
    },
    {
      test: /\.less$/,
      use: [
        MiniCssExtractPlugin.loader,
        {
          loader: 'css',
          options: {
            modules: false,
            minimize: true,
            importLoaders: 2
          }
        },
        {
          loader: 'postcss',
          options: utils.getPostCssOptions()
        },
        {
          loader: 'less',
          options: {
            javascriptEnabled: true
          }
        }
      ]
    },
    {
      test: /\.s(c|a)ss$/,
      use: [
        MiniCssExtractPlugin.loader,
        {
          loader: 'css',
          options: {
            modules: false,
            minimize: true
          }
        },
        {
          loader: 'postcss',
          options: utils.getPostCssOptions()
        },
        'sass'
      ]
    },
    {
      test: /\.styl(us)?$/,
      use: [
        MiniCssExtractPlugin.loader,
        {
          loader: 'css',
          options: {
            modules: false,
            minimize: true
          }
        },
        {
          loader: 'postcss',
          options: utils.getPostCssOptions()
        },
        'stylus'
      ]
    }
  ]
} else {
  // 合并 production rules
  rules = [
    {
      test: /\.css$/,
      use: [
        'style',
        {
          loader: 'css',
          options: {
            modules: abcConfig.cssModule.enable,
            minimize: true,
            localIdentName: abcConfig.cssModule.localIdentName
          }
        },
        {
          loader: 'postcss',
          options: utils.getPostCssOptions()
        }
      ]
    },
    {
      test: /\.less$/,
      use: [
        'style',
        {
          loader: 'css',
          options: {
            modules: abcConfig.cssModule.enable,
            minimize: true,
            localIdentName: abcConfig.cssModule.localIdentName,
            importLoaders: 2
          }
        },
        {
          loader: 'postcss',
          options: utils.getPostCssOptions()
        },
        {
          loader: 'less',
          options: {
            javascriptEnabled: true
          }
        }
      ]
    },
    {
      test: /\.s(c|a)ss$/,
      use: [
        'style',
        {
          loader: 'css',
          options: {
            modules: abcConfig.cssModule.enable,
            minimize: true,
            localIdentName: abcConfig.cssModule.localIdentName
          }
        },
        {
          loader: 'postcss',
          options: utils.getPostCssOptions()
        },
        'sass'
      ]
    },
    {
      test: /\.styl(us)?$/,
      use: [
        'vue-style',
        {
          loader: 'css',
          options: {
            modules: abcConfig.cssModule.enable,
            minimize: true,
            localIdentName: abcConfig.cssModule.localIdentName
          }
        },
        {
          loader: 'postcss',
          options: utils.getPostCssOptions()
        },
        'stylus'
      ]
    }
  ]
}

rules = [rules, config.module.rules, prodConfig.rules || []]

config.module.rules = utils.merge(rules, 'rule')

// 启用 dll 打包
if (dll.enable) {
  config.plugins = [
    new webpack.DllReferencePlugin({
      manifest: require(`${output.path}/vendor.manifest.json`)
    }),
    new HtmlWebpackPlugin({
      template: prodConfig.htmlTemplateUrl || abcConfig.htmlTemplateUrl,
      inject: 'body',
      ...abcConfig.htmlWebpackPluginOptions,
      ...prodConfig.htmlWebpackPluginOptions
    }),
    new HtmlIncludeAssetsPlugin({
      assets: [`vendor.dll.js`],
      append: false,
      hash: function(assetName, hash) {
        const vendorFile = path.resolve(process.cwd(), outputDir, assetName)
        const newHash = md5File.sync(vendorFile)

        return `${assetName}?${newHash.slice(0, 6)}`
      }
    }),
    ...config.plugins
  ]
} else {
  config.plugins = [
    new HtmlWebpackPlugin({
      template: prodConfig.htmlTemplateUrl || abcConfig.htmlTemplateUrl,
      inject: 'body',
      ...abcConfig.htmlWebpackPluginOptions,
      ...prodConfig.htmlWebpackPluginOptions
    }),
    ...config.plugins
  ]
}

// 清除打包目录，默认 vendor 相关文件不删除
if (cleanBuild) {
  config.plugins = [
    new CleanWebpackPlugin(['dist', 'build'], {
      root: process.cwd(),
      exclude: ['vendor.dll.js', 'vendor.manifest.json'],
      verbose: true,
      dry: false
    }),
    ...config.plugins
  ]
}

// 是否启用分析报告功能，方便进行打包后优化分析
if (analyzerReport) {
  config.plugins = [
    new BundleAnalyzerPlugin({
      analyzerPort: 1111,
      generateStatsFile: false
    }),
    ...config.plugins
  ]
}

// 启用了静态资源目录
if (staticPath) {
  config.plugins = [
    new CopyWebpackPlugin([{ from: `${staticPath}`, to: `${output.path}` }]),
    ...config.plugins
  ]
}

// 抽取出单独的 css 文件
if (isExtractCss && !cssModule.enable) {
  config.plugins = [
    new MiniCssExtractPlugin({
      ...{
        filename: '[name].[hash:5].css',
        chunkFilename: '[id].[hash:5].css'
      },
      ...abcConfig.minCssExtract,
      ...prodConfig.minCssExtract
    }),
    ...config.plugins
  ]
}

const plugins = [
  [
    new webpack.DefinePlugin({
      __DEV__: true,
      NODE_ENV: 'daily'
    })
  ],
  config.plugins || [],
  prodConfig.plugins || []
]

config.plugins = utils.merge(plugins, 'plugin')
config.externals = _.merge(
  {},
  config.externals || {},
  abcConfig.externals || {},
  prodConfig.externals || {}
)
config.mode = 'production'
config.optimization = {
  minimizer: [
    new UglifyJsPlugin({
      parallel: true,
      sourceMap: true,
      cache: true,
      uglifyOptions: {
        compress: {
          warnings: false,
          drop_console: true,
          drop_debugger: true
        }
      }
    })
  ]
}

module.exports = config

==> abc-cli-0.2.46.tgz: package/webpack/webpack.daily.config.js <==
/**
 * @fileOverview webpack生产环境配置
 * @author langford@126.com
 */

"use strict"

const path = require("path")
const webpack = require("webpack")
const UglifyJsPlugin = require("uglifyjs-webpack-plugin")
const md5File = require("md5-file")
const HtmlWebpackPlugin = require("html-webpack-plugin")
const HtmlWebpackTagsPlugin = require('html-webpack-tags-plugin')
const CleanWebpackPlugin = require("clean-webpack-plugin")
const MiniCssExtractPlugin = require("mini-css-extract-plugin")
const BundleAnalyzerPlugin = require("webpack-bundle-analyzer")
  .BundleAnalyzerPlugin
const _ = require("lodash")
const config = require("./webpack.base.config")({
  dev: false,
  env: "production"
})
const utils = require("../utils")

const abcConfig = utils.abcConfig
const {
  dll,
  output,
  cleanBuild,
  analyzerReport,
  isExtractCss,
  outputDir,
  cssModule,
  staticPath
} = abcConfig
const prodConfig = abcConfig.env.daily || {}

config.entry =
  JSON.stringify(abcConfig.entry) === "{}"
    ? { index: "./src/index.js" }
    : abcConfig.entry

let rules = []

// 未启用 cssModule 并且 isExtractCss 设置为 true，生成独立的 css 文件
if (isExtractCss && !cssModule.enable) {
  rules = [
    {
      test: /\.css$/,
      use: [
        MiniCssExtractPlugin.loader,
        {
          loader: "css",
          options: {
            modules: false,
            minimize: true
          }
        },
        {
          loader: "postcss",
          options: utils.getPostCssOptions()
        }
      ]
    },
    {
      test: /\.less$/,
      use: [
        MiniCssExtractPlugin.loader,
        {
          loader: "css",
          options: {
            modules: false,
            minimize: true,
            importLoaders: 2
          }
        },
        {
          loader: "postcss",
          options: utils.getPostCssOptions()
        },
        {
          loader: "less",
          options: {
            javascriptEnabled: true
          }
        }
      ]
    },
    {
      test: /\.s(c|a)ss$/,
      use: [
        MiniCssExtractPlugin.loader,
        {
          loader: "css",
          options: {
            modules: false,
            minimize: true
          }
        },
        {
          loader: "postcss",
          options: utils.getPostCssOptions()
        },
        "sass"
      ]
    },
    {
      test: /\.styl(us)?$/,
      use: [
        MiniCssExtractPlugin.loader,
        {
          loader: "css",
          options: {
            modules: false,
            minimize: true
          }
        },
        {
          loader: "postcss",
          options: utils.getPostCssOptions()
        },
        "stylus"
      ]
    }
  ]
} else {
  // 合并 production rules
  rules = [
    {
      test: /\.css$/,
      use: [
        "style",
        {
          loader: "css",
          options: {
            modules: abcConfig.cssModule.enable,
            minimize: true,
            localIdentName: abcConfig.cssModule.localIdentName
          }
        },
        {
          loader: "postcss",
          options: utils.getPostCssOptions()
        }
      ]
    },
    {
      test: /\.less$/,
      use: [
        "style",
        {
          loader: "css",
          options: {
            modules: abcConfig.cssModule.enable,
            minimize: true,
            localIdentName: abcConfig.cssModule.localIdentName,
            importLoaders: 2
          }
        },
        {
          loader: "postcss",
          options: utils.getPostCssOptions()
        },
        {
          loader: "less",
          options: {
            javascriptEnabled: true
          }
        }
      ]
    },
    {
      test: /\.s(c|a)ss$/,
      use: [
        "style",
        {
          loader: "css",
          options: {
            modules: abcConfig.cssModule.enable,
            minimize: true,
            localIdentName: abcConfig.cssModule.localIdentName
          }
        },
        {
          loader: "postcss",
          options: utils.getPostCssOptions()
        },
        "sass"
      ]
    },
    {
      test: /\.styl(us)?$/,
      use: [
        "vue-style",
        {
          loader: "css",
          options: {
            modules: abcConfig.cssModule.enable,
            minimize: true,
            localIdentName: abcConfig.cssModule.localIdentName
          }
        },
        {
          loader: "postcss",
          options: utils.getPostCssOptions()
        },
        "stylus"
      ]
    }
  ]
}

rules = [rules, config.module.rules, prodConfig.rules || []]

config.module.rules = utils.merge(rules, "rule")

// 启用 dll 打包
if (dll.enable) {
  config.plugins = [
    new webpack.DllReferencePlugin({
      manifest: require(`${output.path}/vendor.manifest.json`)
    }),
    ...config.plugins
  ].concat(
    abcConfig.enableHtmlWebpackPlugin
      ? [
          new HtmlWebpackPlugin({
            template: prodConfig.htmlTemplateUrl || abcConfig.htmlTemplateUrl,
            inject: "body",
            ...abcConfig.htmlWebpackPluginOptions,
            ...prodConfig.htmlWebpackPluginOptions
          }),
          new HtmlWebpackTagsPlugin({
            tags: [`vendor.dll.js`],
            append: false,
            useHash: true
            // hash: function(assetName, hash) {
            //   const vendorFile = path.resolve(process.cwd(), outputDir, assetName)
            //   console.log(vendorFile, 222222)
            //   const newHash = md5File.sync(vendorFile)
      
            //   console.log(`${assetName}?${newHash.slice(0, 6)}`, 200000)
      
            //   return `${assetName}?${newHash.slice(0, 6)}`
            // }
          })
        ]
      : []
  )
} else {
  config.plugins = [...config.plugins].concat(
    abcConfig.enableHtmlWebpackPlugin
      ? [
          new HtmlWebpackPlugin({
            template: prodConfig.htmlTemplateUrl || abcConfig.htmlTemplateUrl,
            inject: "body",
            ...abcConfig.htmlWebpackPluginOptions,
            ...prodConfig.htmlWebpackPluginOptions
          })
        ]
      : []
  )
}

// 清除打包目录，默认 vendor 相关文件不删除
if (cleanBuild) {
  config.plugins = [
    new CleanWebpackPlugin(["dist", "build"], {
      root: process.cwd(),
      exclude: ["vendor.dll.js", "vendor.manifest.json"],
      verbose: true,
      dry: false
    }),
    ...config.plugins
  ]
}

// 是否启用分析报告功能，方便进行打包后优化分析
if (analyzerReport) {
  config.plugins = [
    new BundleAnalyzerPlugin({
      analyzerPort: 1111,
      generateStatsFile: false
    }),
    ...config.plugins
  ]
}

// 启用了静态资源目录
if (staticPath) {
  config.plugins = [
    new CopyWebpackPlugin([{ from: `${staticPath}`, to: `${output.path}` }]),
    ...config.plugins
  ]
}

// 抽取出单独的 css 文件
if (isExtractCss && !cssModule.enable) {
  config.plugins = [
    new MiniCssExtractPlugin({
      ...{
        filename: "[name].[hash:5].css",
        chunkFilename: "[id].[hash:5].css"
      },
      ...abcConfig.minCssExtract,
      ...prodConfig.minCssExtract
    }),
    ...config.plugins
  ]
}

const plugins = [
  [
    new webpack.DefinePlugin({
      __DEV__: true,
      NODE_ENV: JSON.stringify("daily")
    })
  ],
  config.plugins || [],
  prodConfig.plugins || []
]

config.plugins = utils.merge(plugins, "plugin")
config.externals = _.merge(
  {},
  config.externals || {},
  abcConfig.externals || {},
  prodConfig.externals || {}
)
config.mode = "production"
config.optimization = {
  minimizer: [
    new UglifyJsPlugin({
      parallel: true,
      sourceMap: true,
      cache: true,
      uglifyOptions: {
        compress: {
          warnings: false,
          drop_console: true,
          drop_debugger: true
        }
      }
    })
  ]
}

module.exports = config
